# -*- coding: utf-8 -*-

class Method:
    sendMessage:    str = 'sendMessage'
    sendDocument:   str = 'sendDocument'
    copyMessage:    str = 'copyMessage'
    forwardMessage: str = 'forwardMessage'
    sendPhoto:      str = 'sendPhoto'
    sendAudio:      str = 'sendAudio'
    sendVideo:      str = 'sendVideo'
    sendAnimation:  str = 'sendAnimation'
    sendVoice:      str = 'sendVoice'
    sendVideoNote:  str = 'sendVideoNote'
    sendMediaGroup: str = 'sendMediaGroup'
    sendLocation:   str = 'sendLocation'
    sendVenue:      str = 'sendVenue'
    sendContact:    str = 'sendContact'
    sendPoll:       str = 'sendPoll'
    sendDice:       str = 'sendDice'
    sendChatAction: str = 'sendChatAction'
    getMe:          str = 'getMe'
    logOut:         str = 'logOut'
    close:          str = 'close'

